==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/ExtensionsV1beta1PodSecurityPolicyListFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface ExtensionsV1beta1PodSecurityPolicyListFluent<A extends ExtensionsV1beta1PodSecurityPolicyListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A addToItems(int index,ExtensionsV1beta1PodSecurityPolicy item);
    public A setToItems(int index,ExtensionsV1beta1PodSecurityPolicy item);
    public A addToItems(ExtensionsV1beta1PodSecurityPolicy... items);
    public A addAllToItems(Collection<ExtensionsV1beta1PodSecurityPolicy> items);
    public A removeFromItems(ExtensionsV1beta1PodSecurityPolicy... items);
    public A removeAllFromItems(Collection<ExtensionsV1beta1PodSecurityPolicy> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<ExtensionsV1beta1PodSecurityPolicy> getItems();
    public List<ExtensionsV1beta1PodSecurityPolicy> buildItems();
    public ExtensionsV1beta1PodSecurityPolicy buildItem(int index);
    public ExtensionsV1beta1PodSecurityPolicy buildFirstItem();
    public ExtensionsV1beta1PodSecurityPolicy buildLastItem();
    public ExtensionsV1beta1PodSecurityPolicy buildMatchingItem(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1PodSecurityPolicyBuilder> predicate);
    public A withItems(List<ExtensionsV1beta1PodSecurityPolicy> items);
    public A withItems(ExtensionsV1beta1PodSecurityPolicy... items);
    public Boolean hasItems();
    public ExtensionsV1beta1PodSecurityPolicyListFluent.ItemsNested<A> addNewItem();
    public ExtensionsV1beta1PodSecurityPolicyListFluent.ItemsNested<A> addNewItemLike(ExtensionsV1beta1PodSecurityPolicy item);
    public ExtensionsV1beta1PodSecurityPolicyListFluent.ItemsNested<A> setNewItemLike(int index,ExtensionsV1beta1PodSecurityPolicy item);
    public ExtensionsV1beta1PodSecurityPolicyListFluent.ItemsNested<A> editItem(int index);
    public ExtensionsV1beta1PodSecurityPolicyListFluent.ItemsNested<A> editFirstItem();
    public ExtensionsV1beta1PodSecurityPolicyListFluent.ItemsNested<A> editLastItem();
    public ExtensionsV1beta1PodSecurityPolicyListFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1PodSecurityPolicyBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ListMeta getMetadata();
    public V1ListMeta buildMetadata();
    public A withMetadata(V1ListMeta metadata);
    public Boolean hasMetadata();
    public ExtensionsV1beta1PodSecurityPolicyListFluent.MetadataNested<A> withNewMetadata();
    public ExtensionsV1beta1PodSecurityPolicyListFluent.MetadataNested<A> withNewMetadataLike(V1ListMeta item);
    public ExtensionsV1beta1PodSecurityPolicyListFluent.MetadataNested<A> editMetadata();
    public ExtensionsV1beta1PodSecurityPolicyListFluent.MetadataNested<A> editOrNewMetadata();
    public ExtensionsV1beta1PodSecurityPolicyListFluent.MetadataNested<A> editOrNewMetadataLike(V1ListMeta item);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,ExtensionsV1beta1PodSecurityPolicyFluent<ExtensionsV1beta1PodSecurityPolicyListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ListMetaFluent<ExtensionsV1beta1PodSecurityPolicyListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/ExtensionsV1beta1PodSecurityPolicyListFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface ExtensionsV1beta1PodSecurityPolicyListFluent<A extends ExtensionsV1beta1PodSecurityPolicyListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,ExtensionsV1beta1PodSecurityPolicy item);
    public A setToItems(int index,ExtensionsV1beta1PodSecurityPolicy item);
    public A addToItems(ExtensionsV1beta1PodSecurityPolicy... items);
    public A addAllToItems(Collection<ExtensionsV1beta1PodSecurityPolicy> items);
    public A removeFromItems(ExtensionsV1beta1PodSecurityPolicy... items);
    public A removeAllFromItems(Collection<ExtensionsV1beta1PodSecurityPolicy> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<ExtensionsV1beta1PodSecurityPolicy> getItems();
    public List<ExtensionsV1beta1PodSecurityPolicy> buildItems();
    public ExtensionsV1beta1PodSecurityPolicy buildItem(int index);
    public ExtensionsV1beta1PodSecurityPolicy buildFirstItem();
    public ExtensionsV1beta1PodSecurityPolicy buildLastItem();
    public ExtensionsV1beta1PodSecurityPolicy buildMatchingItem(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1PodSecurityPolicyBuilder> predicate);
    public Boolean hasMatchingItem(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1PodSecurityPolicyBuilder> predicate);
    public A withItems(List<ExtensionsV1beta1PodSecurityPolicy> items);
    public A withItems(ExtensionsV1beta1PodSecurityPolicy... items);
    public Boolean hasItems();
    public ExtensionsV1beta1PodSecurityPolicyListFluent.ItemsNested<A> addNewItem();
    public ExtensionsV1beta1PodSecurityPolicyListFluent.ItemsNested<A> addNewItemLike(ExtensionsV1beta1PodSecurityPolicy item);
    public ExtensionsV1beta1PodSecurityPolicyListFluent.ItemsNested<A> setNewItemLike(int index,ExtensionsV1beta1PodSecurityPolicy item);
    public ExtensionsV1beta1PodSecurityPolicyListFluent.ItemsNested<A> editItem(int index);
    public ExtensionsV1beta1PodSecurityPolicyListFluent.ItemsNested<A> editFirstItem();
    public ExtensionsV1beta1PodSecurityPolicyListFluent.ItemsNested<A> editLastItem();
    public ExtensionsV1beta1PodSecurityPolicyListFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<ExtensionsV1beta1PodSecurityPolicyBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ListMeta getMetadata();
    public V1ListMeta buildMetadata();
    public A withMetadata(V1ListMeta metadata);
    public Boolean hasMetadata();
    public ExtensionsV1beta1PodSecurityPolicyListFluent.MetadataNested<A> withNewMetadata();
    public ExtensionsV1beta1PodSecurityPolicyListFluent.MetadataNested<A> withNewMetadataLike(V1ListMeta item);
    public ExtensionsV1beta1PodSecurityPolicyListFluent.MetadataNested<A> editMetadata();
    public ExtensionsV1beta1PodSecurityPolicyListFluent.MetadataNested<A> editOrNewMetadata();
    public ExtensionsV1beta1PodSecurityPolicyListFluent.MetadataNested<A> editOrNewMetadataLike(V1ListMeta item);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,ExtensionsV1beta1PodSecurityPolicyFluent<ExtensionsV1beta1PodSecurityPolicyListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ListMetaFluent<ExtensionsV1beta1PodSecurityPolicyListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
